Value

Enum Value 

pub enum Value {
    Undefined,
    String(u32),
    Bool(bool),
    I64(i64),
    U32(u32),
    U64(u64),
    F64(f64),
    FunctionRef(u32),
    HeapRef(u32),
}

Variants



Undefined



String(u32)

a string value from the string interner



Bool(bool)

a boolean value



I64(i64)

a signed 64-bit integer



U32(u32)

an unsigned 32-bit integer



U64(u64)

an unsigned 64-bit integer



F64(f64)

a 64-bit floating point number



FunctionRef(u32)

a reference to a function by its index in the function table



HeapRef(u32)

a reference to an immutable heap object by its index in the heap table

Implementations

Source

impl Value

pub fn get_function_ref(&self) -> Result<u32>

pub fn get_heap_ref(&self) -> Result<u32>

Source

impl Value

pub fn is_undefined(&self) -> bool

pub fn type_of(&self) -> Type

pub fn cast(&self, to: impl AsRef<Type>) -> Result<Value>